@@ -1,5 +1,5 @@
 # Method vSOBI
-vSOBI <- function(X,...) UseMethod("vSOBI")
+vSOBI <- function(X, ...) UseMethod("vSOBI")
 
 # main function for vSOBI
 vSOBI.default <- function (X, k = 1:12, eps = 1e-06, maxiter = 1000, G = "pow", ...){
@@ -17,7 +17,7 @@ vSOBI.default <- function (X, k = 1:12, eps = 1e-06, maxiter = 1000, G = "pow",
   if(length(which(k < 1) != 0)) stop("only non-zero lags allowed")
   nk <- length(k)
   Tk <- array(NA, dim = c(p, p, nk))
-  if (G == "pow") {TIKuse <- TIK} else {TIKuse <- TIKlc}
+  if (G == "pow") {TIKuse <- TIKc} else {TIKuse <- TIKlcc}
   while(crit > eps) {
       for (i in 1:nk){
         Tk[ , , i] <- TIKuse(Y, U, k = k[i], method = 3)
@@ -43,7 +43,7 @@ vSOBI.default <- function (X, k = 1:12, eps = 1e-06, maxiter = 1000, G = "pow",
 vSOBI.ts <- function(X, ...)
 {
   x <- as.matrix(X)
-  RES <- vSOBI.default(x,...)
+  RES <- vSOBI.default(x, ...)
   S <- RES$S
   attr(S, "tsp") <- attr(X, "tsp")
   RES$S <- S
